@@ -469,55 +469,56 @@ class HardwareIOTypeForm(forms.Form):
         fields = ['type', 'parent_hardware', 'child_hardware', 'child_channel', 'hub']
 
 
-from django.forms.models import inlineformset_factory, BaseModelFormSet, BaseInlineFormSet
+from django.forms.models import inlineformset_factory, BaseModelFormSet, BaseInlineFormSet,BaseModelForm
 from data.models.models import HardwareStats, DataTransformer, DataTransformerConstants, HardwareDataTransformer, \
     HardwareStatsDataTransformer
 
-DataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer, fk_name='data_transformer_parent',
-                                                     extra=1,exclude =['updated_at','created_at'],formset=DataTransformerForm)
+# DataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer, fk_name='data_transformer_parent',
+#                                                      extra=1,exclude =['updated_at','created_at'],formset=DataTransformerForm)
 DataConstantsTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformerConstants, extra=1,exclude =['updated_at','created_at'])
 HardwareTransformerInlineFormset = inlineformset_factory(DataTransformer, HardwareDataTransformer, extra=1,exclude =['updated_at','created_at'])
 HardwareStatsTransformerInlineFormset = inlineformset_factory(DataTransformer, HardwareStatsDataTransformer, extra=1,exclude =['updated_at','created_at'])
 
 
-class DataTransformerForm(BaseInlineFormSet,BaseModelFormSet):
+class DataTransformerForm(BaseInlineFormSet):
 
     def __init__(self, *args, **kwargs):
-        super(DataTransformerForm, self).__init__(*args, **kwargs)
         self.DataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,
                                                              fk_name='data_transformer_parent',
                                                              extra=1, exclude=['updated_at', 'created_at'],
-                                                             formset=self.__class__)
+                                                             form=self.__class__)
         for name in self.fields.keys():
             self.fields[name].widget.attrs.update({
                 'class': 'form-control',
             })
+        super(DataTransformerForm, self).__init__(*args, **kwargs)
+
 
     def add_fields(self, form, index):
         super(DataTransformerForm, self).add_fields(form, index)
 
         form.nested_data_transformer_form = self.DataTransformerInlineFormset(
-            instance=form.instance,
-            data=form.data if form.is_bound else None,
-            files=form.files if form.is_bound else None,
+            instance=self.instance.datatransformer_set,
+            data=self.data if self.is_bound else None,
+            files=self.files if self.is_bound else None,
             extra=1)
 
         form.nested_constants_form = DataConstantsTransformerInlineFormset(
-            instance=form.instance,
-            data=form.data if form.is_bound else None,
-            files=form.files if form.is_bound else None,
+            instance=self.instance,
+            data=self.data if self.is_bound else None,
+            files=self.files if self.is_bound else None,
             extra=1)
 
         form.nested_hardware_outputs_form = HardwareTransformerInlineFormset(
-            instance=form.instance,
-            data=form.data if form.is_bound else None,
-            files=form.files if form.is_bound else None,
+            instance=self.instance,
+            data=self.data if self.is_bound else None,
+            files=self.files if self.is_bound else None,
             extra=1)
 
         form.nested_hardware_stats_form = HardwareStatsTransformerInlineFormset(
-            instance=form.instance,
-            data=form.data if form.is_bound else None,
-            files=form.files if form.is_bound else None,
+            instance=self.instance,
+            data=self.data if self.is_bound else None,
+            files=self.files if self.is_bound else None,
             extra=1)
 
     class Meta:
