@@ -389,7 +389,9 @@ class AccessoryViewSet(viewsets.ModelViewSet):
             data_transformer = accessory.datatransformer
             formset = DataTransformerForm(instance=data_transformer)
         else:
-            formset = DataTransformerForm()
+            formset = DataTransformerForm(initial={'accessory': accessory})
+
+
 
 
         if request.accepted_renderer.format == 'html':
